@@ -2,15 +2,14 @@ from __future__ import annotations
 
 from typing import Any
 
+from . import gql_mutations as gm
+from . import gql_queries as gq
 from .const import ENDPOINT
 from .exception_classes import ErrorMSG, LoginError, NoAdminError
 from .graphql_client import GraphqlClient
 from .handler_gql import HandlerGQL
 from .status import EmailAndPhoneVerificationTypeV2, NormalStatus, UserContactType
 
-from . import gql_mutations as gm
-from . import gql_queries as gq
-
 
 class GQLHandler(HandlerGQL):
     def __init__(
@@ -88,7 +87,9 @@ class GQLHandler(HandlerGQL):
             if self.userId == id:
                 if contact["guardianType"] == "FIRST":
                     data: dict[str, Any] = self.runAuthorizedGqlQuery(query, variables, key).get("data", {})
-                    return data.get(key, False)
+                    for k in data.keys():
+                        if k.upper() == key.upper():
+                            return data.get(k, False)
         raise NoAdminError()
 
     ########## SECTION QUERY start ##########
@@ -374,7 +375,7 @@ class GQLHandler(HandlerGQL):
 
     def shutdown(self, wuid: str) -> bool:
         # ownUser id
-        return self.isAdmin(wuid, gm.WATCH_M.get("shutdownM", ""), {"uid": wuid}, "shutDown")
+        return self.isAdmin(wuid, gm.WATCH_M.get("shutdownM", ""), {"uid": wuid}, "ShutDown")
 
     def reboot(self, wuid: str) -> bool:
         # ownUser id
